@@ -4,7 +4,7 @@
 ;;
 ;; Author: Per Abrahamsen <abraham@dina.kvl.dk>
 ;; Keywords: help, faces
-;; Version: 1.65
+;; Version: 1.82
 ;; X-URL: http://www.dina.kvl.dk/~abraham/custom/
 
 ;;; Commentary:
@@ -19,9 +19,27 @@
 
 ;;; Compatibility.
 
+(if (string-match "XEmacs" emacs-version)
+    (defun custom-face-background (face &optional frame)
+      ;; Specifiers suck!
+      "Return the background color name of face FACE, or nil if unspecified."
+      (color-instance-name (specifier-instance (face-background face) frame)))
+  (defalias 'custom-face-background 'face-background))
+
+(if (string-match "XEmacs" emacs-version)
+    (defun custom-face-foreground (face &optional frame)
+      ;; Specifiers suck!
+      "Return the background color name of face FACE, or nil if unspecified."
+      (color-instance-name (specifier-instance (face-foreground face) frame)))
+  (defalias 'custom-face-foreground 'face-foreground))
+
+(defalias 'custom-face-font-name (if (string-match "XEmacs" emacs-version)
+				     'face-font-name
+				   'face-font))
+
 (eval-and-compile
   (unless (fboundp 'frame-property)
-    ;; XEmacs function missing in Emacs 19.34.
+    ;; XEmacs function missing in Emacs.
     (defun frame-property (frame property &optional default)
       "Return FRAME's value for property PROPERTY."
       (or (cdr (assq property (frame-parameters frame)))
@@ -31,13 +49,13 @@
     ;; XEmacs function missing in Emacs.
     (defun face-doc-string (face)
       "Get the documentation string for FACE."
-      (get face 'face-doc-string)))
+      (get face 'face-documentation)))
 
   (unless (fboundp 'set-face-doc-string)
     ;; XEmacs function missing in Emacs.
     (defun set-face-doc-string (face string)
       "Set the documentation string for FACE to STRING."
-      (put face 'face-doc-string string))))
+      (put face 'face-documentation string))))
 
 (unless (fboundp 'x-color-values)
   ;; Emacs function missing in XEmacs 19.14.
@@ -162,9 +180,8 @@ examine the brightness for you."
 					   (or (frame-property
 						frame
 						'background-color)
-					       (color-instance-name
-						(specifier-instance
-						 (face-background 'default))))
+					       (custom-face-background
+						'default))
 					 (error nil)))
 			   (or (string-match "XEmacs" emacs-version)
 			       window-system)
@@ -232,23 +249,28 @@ examine the brightness for you."
 (defconst custom-face-attributes
   '((:bold (toggle :format "Bold: %[%v%]\n"
 		   :help-echo "Control whether a bold font should be used.")
-	   custom-set-face-bold)
+	   custom-set-face-bold 
+	   custom-face-bold)
     (:italic (toggle :format "Italic: %[%v%]\n"
 		     :help-echo "\
 Control whether an italic font should be used.")
-	     custom-set-face-italic)
+	     custom-set-face-italic
+	     custom-face-italic)
     (:underline (toggle :format "Underline: %[%v%]\n"
 			:help-echo "\
 Control whether the text should be underlined.")
-		set-face-underline-p)
+		set-face-underline-p
+		face-underline-p)
     (:foreground (color :tag "Foreground"
 			:value "black"
 			:help-echo "Set foreground color.")
-		 set-face-foreground)
+		 set-face-foreground
+		 custom-face-foreground)
     (:background (color :tag "Background"
 			:value "white"
 			:help-echo "Set background color.")
-		 set-face-background)
+		 set-face-background
+		 custom-face-background)
     ;;    (:invert (const :format "Invert Face\n" 
     ;;		    :sibling-args (:help-echo "
     ;;Reverse the foreground and background color.
@@ -259,16 +281,19 @@ Control whether the text should be underlined.")
     ;;	       (custom-invert-face face frame)))
     (:stipple (editable-field :format "Stipple: %v"
 			      :help-echo "Name of background bitmap file.")
-	      set-face-stipple))
+	      set-face-stipple custom-face-stipple))
   "Alist of face attributes. 
 
-The elements are of the form (KEY TYPE SET) where KEY is a symbol
+The elements are of the form (KEY TYPE SET GET) where KEY is a symbol
 identifying the attribute, TYPE is a widget type for editing the
-attibute, SET is a function for setting the attribute value.
+attibute, SET is a function for setting the attribute value, and GET is a function for getiing the attribute value. 
 
 The SET function should take three arguments, the face to modify, the
 value of the attribute, and optionally the frame where the face should
-be changed.")
+be changed.
+
+The GET function should take two arguments, the face to examine, and
+optonally the frame where the face should be examined.")
 
 (defun custom-face-attributes-set (face frame &rest atts)
   "For FACE on FRAME set the attributes [KEYWORD VALUE]....
@@ -284,49 +309,108 @@ If FRAME is nil, set the default face."
 	  (funcall fun face value frame)
 	(error nil)))))
 
+(defun custom-face-attributes-get (face frame)
+  "For FACE on FRAME get the attributes [KEYWORD VALUE]....
+Each keyword should be listed in `custom-face-attributes'.
+
+If FRAME is nil, use the default face."
+  (condition-case nil
+      ;; Attempt to get `font.el' from w3.
+      (require 'font)
+    (error nil))
+  (let ((atts custom-face-attributes)
+	att result get)
+    (while atts
+      (setq att (car atts)
+	    atts (cdr atts)
+	    get (nth 3 att))
+      (when get 
+	(let ((answer (funcall get face frame)))
+	  (unless (equal answer (funcall get 'default frame))
+	    (when (widget-apply (nth 1 att) :match answer)
+	      (setq result (cons (nth 0 att) (cons answer result))))))))
+    result))
+
 (defun custom-set-face-bold (face value &optional frame)
   "Set the bold property of FACE to VALUE."
   (if value
       (make-face-bold face frame)
     (make-face-unbold face frame)))
 
+(defun custom-face-bold (face &rest args)
+  "Return non-nil if the font of FACE is bold."
+  (let* ((font (apply 'custom-face-font-name face args))
+	 (fontobj (font-create-object font)))
+    (font-bold-p fontobj)))
+
 (defun custom-set-face-italic (face value &optional frame)
   "Set the italic property of FACE to VALUE."
   (if value
       (make-face-italic face frame)
     (make-face-unitalic face frame)))
 
+(defun custom-face-italic (face &rest args)
+  "Return non-nil if the font of FACE is italic."
+  (let* ((font (apply 'custom-face-font-name face args))
+	 (fontobj (font-create-object font)))
+    (font-italic-p fontobj)))
+
+(defun custom-face-stipple (face &rest args)
+  "Return the name of the stipple file used for FACE."
+  (if (string-match "XEmacs" emacs-version)
+      (let ((image  (apply 'specifier-instance 
+			   (face-background-pixmap face) args)))
+	(when image 
+	  (image-instance-file-name image)))
+    (apply 'face-stipple face args)))
+
 (when (string-match "XEmacs" emacs-version)
   ;; Support for special XEmacs font attributes.
   (autoload 'font-create-object "font" nil)
 
-  (unless (fboundp 'face-font-name)
-    (defun face-font-name (face &rest args)
-      (apply 'face-font face args)))
-
   (defun custom-set-face-font-size (face size &rest args)
     "Set the font of FACE to SIZE"
-    (let* ((font (apply 'face-font-name face args))
+    (let* ((font (apply 'custom-face-font-name face args))
 	   (fontobj (font-create-object font)))
       (set-font-size fontobj size)
       (apply 'font-set-face-font face fontobj args)))
 
+  (defun custom-face-font-size (face &rest args)
+    "Return the size of the font of FACE as a string."
+    (let* ((font (apply 'custom-face-font-name face args))
+	   (fontobj (font-create-object font)))
+      (format "%d" (font-size fontobj))))
+
   (defun custom-set-face-font-family (face family &rest args)
-    "Set the font of FACE to FAMILY"
-    (let* ((font (apply 'face-font-name face args))
+    "Set the font of FACE to FAMILY."
+    (let* ((font (apply 'custom-face-font-name face args))
 	   (fontobj (font-create-object font)))
       (set-font-family fontobj family)
       (apply 'font-set-face-font face fontobj args)))
 
-  (nconc custom-face-attributes
-	 '((:family (editable-field :format "Font Family: %v"
-				    :help-echo "\
+  (defun custom-face-font-family (face &rest args)
+    "Return the name of the font family of FACE."
+    (let* ((font (apply 'custom-face-font-name face args))
+	   (fontobj (font-create-object font)))
+      (font-family fontobj)))
+
+  (setq custom-face-attributes
+	(append '((:family (editable-field :format "Font Family: %v"
+					  :help-echo "\
 Name of font family to use (e.g. times).") 
-		    custom-set-face-font-family)
-	   (:size (editable-field :format "Size: %v"
-				  :help-echo "\
+			  custom-set-face-font-family
+			  custom-face-font-family)
+		  (:size (editable-field :format "Size: %v"
+					 :help-echo "\
 Text size (e.g. 9pt or 2mm).")
-		  custom-set-face-font-size))))
+			 custom-set-face-font-size
+			 custom-face-font-size)
+		  (:strikethru (toggle :format "Strikethru: %[%v%]\n"
+				      :help-echo "\
+Control whether the text should be strikethru.")
+			       set-face-strikethru-p
+			       face-strikethru-p))
+		custom-face-attributes)))
 
 ;;; Frames.
 
@@ -425,19 +509,16 @@ If FRAME is nil or omitted, initialize them for all frames."
 		(initialize-face-resources symbol frame))))
 	  (face-list)))
 
+;;;###autoload
 (defun custom-initialize-frame (&optional frame)
   "Initialize local faces for FRAME if necessary.
-If FRAME is missing or nil, the first member (frame-list) is used."
+If FRAME is missing or nil, the first member of (frame-list) is used."
   (unless frame
     (setq frame (car (frame-list))))
   (unless (equal (custom-get-frame-properties) 
 		 (custom-get-frame-properties frame))
     (custom-initialize-faces frame)))
 
-;; Enable.  This should go away when bundled with Emacs.
-(unless (string-match "XEmacs" emacs-version)
-  (add-hook 'after-make-frame-hook 'custom-initialize-frame))
-
 ;;; Initializing.
 
 (and (fboundp 'make-face)
